@@ -102,6 +102,7 @@ class Model(MetricsLayerBase):
         "type",
         "name",
         "label",
+        "hidden",
         "connection",
         "week_start_day",
         "timezone",
@@ -137,6 +138,10 @@ class Model(MetricsLayerBase):
             return self._definition["fiscal_month_offset"]
         return 0
 
+    @property
+    def hidden(self) -> bool:
+        return bool(self._definition.get("hidden", False))
+
     @property
     def access_grants(self):
         if "access_grants" in self._definition:
