@@ -3,11 +3,12 @@ import os
 from copy import deepcopy
 from typing import Any
 
+from metrics_layer.core.exceptions import MetricsLayerException
 from metrics_layer.core.model.definitions import Definitions
 from metrics_layer.core.sql.query_errors import ArgumentError
 
 
-class MetricsLayerConnectionError(Exception):
+class MetricsLayerConnectionError(MetricsLayerException):
     pass
 
 
@@ -461,7 +462,9 @@ class BigQueryConnection(BaseConnection):
                 with open(path, "r") as f:
                     return json.load(f)
         else:
-            raise TypeError(f"BigQuery credentials json had wrong type: {type(creds)} for value {creds}")
+            raise MetricsLayerException(
+                f"BigQuery credentials json had wrong type: {type(creds)} for value {creds}"
+            )
 
 
 connection_class_lookup = {
